aboutsummaryrefslogtreecommitdiff
path: root/internal/feed/item.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/feed/item.go')
-rw-r--r--internal/feed/item.go10
1 files changed, 6 insertions, 4 deletions
diff --git a/internal/feed/item.go b/internal/feed/item.go
index 39f41ba..f7dd506 100644
--- a/internal/feed/item.go
+++ b/internal/feed/item.go
@@ -4,6 +4,7 @@ import (
"encoding/base64"
"encoding/json"
"fmt"
+ "strings"
"time"
"github.com/google/uuid"
@@ -44,12 +45,13 @@ func (item *Item) Date() string {
return item.Updated
}
// Creator returns the name of the creating author.
func (item *Item) Creator() string {
- if item.Author != nil {
- return item.Author.Name
+ names := make([]string, len(item.Authors))
+ for i, p := range item.Authors {
+ names[i] = p.Name
}
- return ""
+ return strings.Join(names, ", ")
}
func (item *Item) FeedLink() string {
@@ -44,12 +45,13 @@ func (item *Item) Date() string {
return item.Updated
}
-// Creator returns the name of the creating author.
+// Creator returns the name of the creating authors (comma separated).
func (item *Item) Creator() string {